@@ -1,7 +1,7 @@
 package Algorithm::AM;
 use strict;
 use warnings;
-our $VERSION = '3.08';
+our $VERSION = '3.09';
 # ABSTRACT: Classify data with Analogical Modeling
 use feature 'state';
 use Carp;
@@ -327,7 +327,7 @@ Algorithm::AM - Classify data with Analogical Modeling
 
 =head1 VERSION
 
-version 3.08
+version 3.09
 
 =head1 SYNOPSIS
 
@@ -356,44 +356,48 @@ Analogical Modeling (or AM) was developed as an exemplar-based
 approach to modeling language usage, and has also been found useful
 in modeling other "sticky" phenomena. AM is especially suited to this
 because it predicts probabilistic occurrences instead of assigning
-static labels to instances.
+static labels for instances.
 
-The AM algorithm can be called a
+AM was not designed to be a classifier, but as a cognitive theory explaining
+variation in human behavior. As such, though in practice it is often used
+like any other machine learning classifier, there are fine theoretical points
+in which it differs. As a theory of human behavior, much of the value in its
+predictions lies in matching observed human behavior, including non-determinism
+and degradations in accuracy caused by paucity of data.
+
+The AM algorithm could be called a
 L<probabilistic|http://en.wikipedia.org/wiki/Probabilistic_classification>,
 L<instance-based|http://en.wikipedia.org/wiki/Instance-based_learning>
 classifier. However, the probabilities given for each classification
 are not degrees of certainty, but actual probabilities of occurring
-in real usage. Thus in AM literature the classification is supposed
-to produce dynamic "outcomes", not static "labels". In AM proper,
-the last step of classification is to produce an
-outcome at random based on the calculated probability distribution.
-AM therefore predicts that "sticky" phenomena are "sticky"
-because they vary probabilistically, defying absolute prediction.
+in real usage. AM models "sticky" phenomena as being intrinsically
+sticky, not as deterministic phenomena that just require more data to be
+predicted perfectly.
 
-In this software, an outcome can be chosen probabilistically using
-L<Algorithm::AM::Result/random_outcome>. However, in practice,
-usually only
-the highest-probability prediction(s) are used for classification
-tasks. These can be retrieved via
-L<Algorithm::AM::Result/winners>, or L<Algorithm::AM::Result/result>
-if you're just interested in classification accuracy on a test set.
-The entire outcome probability distribution can also be retrieved via
-L<Algorithm::AM::Result/scores_normalized>. See
-L<Algorithm::AM::Result> for other types of information available
+Though it is possible to choose an outcome probabilistically, in practice
+users are generally interested in either the full predicted probability
+distribution
+or the outcome with the highest probability. The entire outcome probability
+distribution can be retrieved via
+L<Algorithm::AM::Result/scores_normalized>. The highest probability outcome
+can be retrieved via L<Algorithm::AM::Result/winners>.
+If you're only interested in classification accuracy based on the highest
+probability outcome (treating AM like any other classification algorithm),
+use L<Algorithm::AM::Result/result>.
+See L<Algorithm::AM::Result> for other types of information available
 after classification. See L<Algorithm::AM::algorithm> for details
 on the actual mechanism of classification.
 
-Outside of the C<random_outcome> method mentioned above, the rest
-of the
-software uses more general machine learning terminology. What would
-properly be called an "exemplar" is referred to simply as an "item",
-and, as is customary, "training" and "test" sets are used, even
-though AM never does any actual "training". Training items
-are assigned "class labels" (not "outcomes"), and classification
-results in a set of scores (or probabilities) for different "class
-labels", even though they would properly be called "outcomes".
-Finally, items contain vectors of "features", which were called
-"variables" in previous versions of this software.
+AM practitioners often use specialized terminolgy, but most of this
+terminology has more common machine learning terminology equivalents.
+This software tries to use the specialized terminology for end-user-facing
+tasks like reports or command-line API's.
+
+AM uses the term "exemplar" where ML uses "training instance". Historically
+the AM software used the word "item" to refer to either training or test
+instances, and that term is retained here. AM has "outcomes" and ML has
+"class labels" (we use the latter). Finally, AM practitioners refer to
+"variables", and we use the ML term "feature" here.
 
 =head1 EXPORTS
 
