@@ -1,7 +1,7 @@
 package Algorithm::AM::DataSet;
 use strict;
 use warnings;
-our $VERSION = '3.08';
+our $VERSION = '3.09';
 # ABSTRACT: Manage data used by Algorithm::AM
 use Carp;
 use Algorithm::AM::DataSet::Item;
@@ -242,6 +242,8 @@ sub _class_for_index {
 #pod separating characters, so here the features are f, e, a, t, u, r,
 #pod e, and s.
 #pod
+#pod Lines beginning with a pound character (C<#>) are ignored.
+#pod
 #pod =cut
 sub dataset_from_file {## no critic (RequireArgUnpacking)
     my (%opts) = (
@@ -311,6 +313,8 @@ sub _read_data_sub {
         # grab the next non-blank line from the file
         while($line = <$data_fh>){
             $line_num++;
+            # skip comments
+            next if $line =~ m/^\s*#/;
             # cross-platform chomp
             $line =~ s/\R$//;
             $line =~ s/^\s+|\s+$//g;
@@ -354,7 +358,7 @@ Algorithm::AM::DataSet - Manage data used by Algorithm::AM
 
 =head1 VERSION
 
-version 3.08
+version 3.09
 
 =head1 SYNOPSIS
 
@@ -440,6 +444,8 @@ whitespace. Each feature value must be a single character with no
 separating characters, so here the features are f, e, a, t, u, r,
 e, and s.
 
+Lines beginning with a pound character (C<#>) are ignored.
+
 =head1 SEE ALSO
 
 For information on creating data sets, see the appendices in
